@@ -11,7 +11,7 @@ try:
 except:
     pass
 
-discovery = "https://discovery.data.storemesh.com"
+discovery = os.environ.get('discovery_url', "https://discovery.data.storemesh.com")
 
 _base_discovery_api = "https://api.discovery.data.storemesh.com"
 _internal_base_discovery_api = "http://backend:8000"
